@@ -8,3 +8,6 @@ def run():
     print("Initializing...")
     from eslearn.GUI.easylearn_main_run import main
     main()
+
+if __name__ == "__main__":
+    run()
\ No newline at end of file
